#!/usr/bin/env python3
#
# Copyright 2021 Graviti. Licensed under MIT License.
#
# pylint: disable=invalid-name

"""Dataloader of the NeolixOD dataset."""

from tensorbay.opendataset.NeolixOD.loader import NeolixOD

__all__ = ["NeolixOD"]
